Test Report

# Summary

Started | 2025-09-01 13:20:17
Ended | 2025-09-01 13:20:22
Duration | 0:00:04.638335
Total run time | 0:00:03.234043

14 passed

# Warnings

## Warnings 22

- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307
- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307
- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307
- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307
- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307
- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307
- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307
- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307
- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307
- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307
- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307

# Tests

## tests/test_cli_parser.py 7 0:00:00.978068

### PASSED Test_CLIParser::test_clean_snow_grain_size_retrieval 0:00:00.274286

Started | 2025-09-01 13:20:18
Ended | 2025-09-01 13:20:18
Duration | 0:00:00.274286
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Writing GeoArray of size (3, 2, 10) to /tmp/tmp9kj9zhkv/output_clean.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmp9kj9zhkv/output_3_albedo.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmp9kj9zhkv/output_4_BOAR.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmp9kj9zhkv/output_5_PA.bsq.
    Writing GeoArray of size (3, 2, 6) to /tmp/tmp9kj9zhkv/output_6_BBA.bsq.

#### Teardown

### PASSED Test_CLIParser::test_main 0:00:00.226109

Started | 2025-09-01 13:20:18
Ended | 2025-09-01 13:20:19
Duration | 0:00:00.226109
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Writing GeoArray of size (3, 2, 10) to /tmp/tmpjwk2soai/output_clean.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmpjwk2soai/output_3_albedo.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmpjwk2soai/output_4_BOAR.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmpjwk2soai/output_5_PA.bsq.
    Writing GeoArray of size (3, 2, 6) to /tmp/tmpjwk2soai/output_6_BBA.bsq.

#### Teardown

### PASSED Test_CLIParser::test_main_no_args 0:00:00.009647

Started | 2025-09-01 13:20:19
Ended | 2025-09-01 13:20:19
Duration | 0:00:00.009647
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_no_args 0:00:00.006408

Started | 2025-09-01 13:20:19
Ended | 2025-09-01 13:20:19
Duration | 0:00:00.006408
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_acceptance 0:00:00.006705

Started | 2025-09-01 13:20:19
Ended | 2025-09-01 13:20:19
Duration | 0:00:00.006705
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_polluted_snow_albedo_impurities_retrieval 0:00:00.218679

Started | 2025-09-01 13:20:19
Ended | 2025-09-01 13:20:19
Duration | 0:00:00.218679
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Writing GeoArray of size (3, 2, 5) to /tmp/tmps6tkb0nn/out.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmps6tkb0nn/output_impurity_rs.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmps6tkb0nn/output_impurity_rp.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmps6tkb0nn/output_imp_bba_plane.bsq.

#### Teardown

### PASSED Test_CLIParser::test_polluted_snow_broadband_albedo_retrieval 0:00:00.236234

Started | 2025-09-01 13:20:19
Ended | 2025-09-01 13:20:19
Duration | 0:00:00.236234
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Writing GeoArray of size (3, 2, 10) to /tmp/tmpnbaw18g9/output_clean.bsq.
    Writing GeoArray of size (3, 2, 5) to /tmp/tmpnbaw18g9/out.bsq.
    Writing GeoArray of size (3, 2, 15) to /tmp/tmpnbaw18g9/output_impurity.bsq.
    Writing GeoArray of size (3, 2, 6) to /tmp/tmpnbaw18g9/output_BBA.bsq.

#### Teardown

## tests/test_io.py 4 0:00:01.634143

### PASSED TestReaderEnMAPL1C::test_create_vrt 0:00:01.124170

Started | 2025-09-01 13:20:19
Ended | 2025-09-01 13:20:20
Duration | 0:00:01.124170
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED TestReaderEnMAPL1C::test_to_toa_reflectance 0:00:00.191080

Started | 2025-09-01 13:20:20
Ended | 2025-09-01 13:20:20
Duration | 0:00:00.191080
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED TestReaderEnMAPL1C::test_to_toa_reflectance_with_band_list 0:00:00.165137

Started | 2025-09-01 13:20:20
Ended | 2025-09-01 13:20:21
Duration | 0:00:00.165137
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED TestReaderEnMAPL1C::test_to_toa_reflectance_with_band_list_single_band 0:00:00.153756

Started | 2025-09-01 13:20:21
Ended | 2025-09-01 13:20:21
Duration | 0:00:00.153756
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_retrieval.py 3 0:00:00.621832

### PASSED TestRetrieval::test_run_clean_snow_grain_size_retrieval 0:00:00.192867

Started | 2025-09-01 13:20:21
Ended | 2025-09-01 13:20:21
Duration | 0:00:00.192867
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    The output directory /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output does not exist. Creating it now.
    Writing GeoArray of size (3, 2, 10) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_clean.bsq.

#### Teardown

### PASSED TestRetrieval::test_run_polluted_snow_albedo_impurities_retrieval 0:00:00.209797

Started | 2025-09-01 13:20:21
Ended | 2025-09-01 13:20:21
Duration | 0:00:00.209797
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Writing GeoArray of size (3, 2, 5) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/out.bsq.
    Writing GeoArray of size (3, 2, 224) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_impurity_rs.bsq.
    Writing GeoArray of size (3, 2, 224) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_impurity_rp.bsq.
    Writing GeoArray of size (3, 2, 224) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_imp_bba_plane.bsq.

#### Teardown

### PASSED TestRetrieval::test_run_polluted_snow_broadband_albedo_retrieval 0:00:00.219167

Started | 2025-09-01 13:20:21
Ended | 2025-09-01 13:20:21
Duration | 0:00:00.219167
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Writing GeoArray of size (3, 2, 10) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_clean.bsq.
    Writing GeoArray of size (3, 2, 5) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/out.bsq.
    Writing GeoArray of size (3, 2, 15) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_impurity.bsq.
    Writing GeoArray of size (3, 2, 6) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_BBA.bsq.
    0.2061607837677002

#### Teardown